AnkiVim
=======
This package provides 


.. include:: ../../README.rst
    :end-before: Documentation

.. toctree::
   :caption: Contents:
   :maxdepth: 3

   intro
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
